from dataclasses import dataclass
from datetime import datetime
from bgutils.spider.BaseSpider import BaseSpider
@dataclass
class SpiderHouse(BaseSpider):
    title: str #房产标题
    addr: str  #地址
    houseinfo: str #房屋信息
    houseurl: str #房屋url
    price : str #房总价
    unitprice : str #房单价
    img : str #图片
    city : str  # 所在城市

    def __init__(self, username, collector, rawurl, rawdata):
        self.username = username #采集者学号
        self.collector= collector #采集者姓名
        self.topic = "house_data" #采集题材
        self.rawurl= rawurl #采集的原始url地址
        self.rawdata = rawdata #采集的原始数据，如记录行的json内容
        self.coll_time = datetime.now() #采集时间，实体初始方法自动填充







from dataclasses import dataclass
from datetime import datetime

from bgutils.spider.BaseSpider import BaseSpider

@dataclass
class SpiderGoods(BaseSpider):
    id: str #商品ID
    title: str #商品标题
    url: str #商品url
    price: str #商品的单价
    pic: str #商品的图片url
    time_sort: str #商品的顺序号

    def __init__(self, username, collector, rawurl, rawdata):
        self.username = username #采集者学号
        self.collector= collector #采集者姓名
        self.topic = "goods_data" #采集题材
        self.rawurl= rawurl  #采集的原始url地址
        self.rawdata = rawdata #采集的原始数据，如记录行的json内容
        self.coll_time = datetime.now() #采集时间，实体初始方法自动填充



from dataclasses import dataclass
from datetime import datetime

from bgutils.spider.BaseSpider import BaseSpider

@dataclass
class SpiderData(BaseSpider):
    id: str
    title: str
    url: str
    price: str
    pic: str
    time_sort: str

    def __init__(self, username, collector, rawurl, rawdata):
        self.username = username
        self.collector= collector
        self.topic = "goods_data"
        self.rawurl= rawurl
        self.rawdata = rawdata
        self.coll_time = datetime.now()




from __future__ import print_function
from setuptools import setup, find_packages

setup(
    name="bgutils_hddly",
    version="1.1.78",
    author="hddly",  #作者名字
    author_email="goodym@163.com",
    description="bigdata utils.",
    license="MIT",
    url="https://biglab.site",  #github地址或其他地址
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Environment :: Web Environment",
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12'
    ],
    install_requires=[
            'pandas>=1.1.0',  #所需要包的版本号
            'numpy>=1.14.0',   #所需要包的版本号
            'paramiko>=2.11.0',
            'pymongo>=3.11.1',
            'requests>=2.26.0',
            'seaborn>=0.11.2',
            'SQLAlchemy>=1.4.27',
            'moviepy>=1.0.3'
    ],
    zip_safe=True,
)

# beautifulsoup4==4.11.1
# C3==0.1
# chardet==4.0.0
# django_recaptcha==3.0.0
# matplotlib==3.2.2
# setuptools==65.4.1

